@@ -39,11 +39,10 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtkmisc.h>
 #include <gtk/gtkscrolledwindow.h>
-#include <bonobo/bonobo-i18n.h>
+#include <glib/gi18n.h>
 
 static void ephy_bookmark_properties_class_init (EphyBookmarkPropertiesClass *klass);
 static void ephy_bookmark_properties_init (EphyBookmarkProperties *editor);
-static void ephy_bookmark_properties_finalize (GObject *object);
 static void ephy_bookmark_properties_set_property (GObject *object,
 		                               guint prop_id,
 		                               const GValue *value,
@@ -53,6 +52,8 @@ static void ephy_bookmark_properties_get_property (GObject *object,
 		                               GValue *value,
 		                               GParamSpec *pspec);
 
+#define EPHY_BOOKMARK_PROPERTIES_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_BOOKMARK_PROPERTIES, EphyBookmarkPropertiesPrivate))
+
 struct EphyBookmarkPropertiesPrivate
 {
 	EphyBookmarks *bookmarks;
@@ -109,8 +110,6 @@ ephy_bookmark_properties_class_init (EphyBookmarkPropertiesClass *klass)
 
 	parent_class = g_type_class_peek_parent (klass);
 
-	object_class->finalize = ephy_bookmark_properties_finalize;
-
 	object_class->set_property = ephy_bookmark_properties_set_property;
 	object_class->get_property = ephy_bookmark_properties_get_property;
 
@@ -119,7 +118,7 @@ ephy_bookmark_properties_class_init (EphyBookmarkPropertiesClass *klass)
 					 g_param_spec_object ("bookmarks",
 							      "Bookmarks set",
 							      "Bookmarks set",
-							      EPHY_BOOKMARKS_TYPE,
+							      EPHY_TYPE_BOOKMARKS,
 							      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 
 	g_object_class_install_property (object_class,
@@ -128,23 +127,8 @@ ephy_bookmark_properties_class_init (EphyBookmarkPropertiesClass *klass)
 							       "Bookmark",
 							       "Bookmark",
 							       G_PARAM_READWRITE));
-}
 
-static void
-ephy_bookmark_properties_finalize (GObject *object)
-{
-	EphyBookmarkProperties *editor;
-
-	g_return_if_fail (object != NULL);
-	g_return_if_fail (EPHY_IS_BOOKMARK_PROPERTIES (object));
-
-	editor = EPHY_BOOKMARK_PROPERTIES (object);
-
-	g_return_if_fail (editor->priv != NULL);
-
-	g_free (editor->priv);
-
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	g_type_class_add_private (object_class, sizeof(EphyBookmarkPropertiesPrivate));
 }
 
 static void
@@ -258,13 +242,9 @@ title_entry_changed_cb (GtkWidget *entry, EphyBookmarkProperties *props)
 static void
 location_entry_changed_cb (GtkWidget *entry, EphyBookmarkProperties *props)
 {
-	char *text;
-
-	text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
 	ephy_bookmarks_set_address (props->priv->bookmarks,
 				    props->priv->bookmark,
-			            text);
-	g_free (text);
+			            gtk_entry_get_text (GTK_ENTRY (entry)));
 }
 
 static void
@@ -440,11 +420,11 @@ build_ui (EphyBookmarkProperties *editor)
 static void
 ephy_bookmark_properties_init (EphyBookmarkProperties *editor)
 {
-	editor->priv = g_new0 (EphyBookmarkPropertiesPrivate, 1);
+	editor->priv = EPHY_BOOKMARK_PROPERTIES_GET_PRIVATE (editor);
 
 	editor->priv->bookmark = NULL;
 	editor->priv->tb_model = EPHY_TOOLBARS_MODEL
-		(ephy_shell_get_toolbars_model (ephy_shell));
+		(ephy_shell_get_toolbars_model (ephy_shell, FALSE));
 }
 
 GtkWidget *
